JSDoc: Module: SlickGridColors

# Module: SlickGridColors

SlickGrid color editor and formatter.

Source:
  - color-editor.js, line 1

### Classes

ColorEditor

### Methods

#### (static) ColorFormatter(row, cell, value, columnDef, dataContext) → {string}

Function to format colors for the SlickGrid object.

This formatter is heavily based in the examples found in slick.formattters.js and is only intended to be used with ColorFormatter.

##### Parameters:

Name | Type | Description
--- | --- | ---
`row` | integer | SlickGrid row.
`cell` | integer | SlickGrid cell.
`value` | integer | string | bool | The value in the row.
`columnDef` | object | SlickGrid column definition.
`dataContext` | object | Data model of the SlickGrid object.

Source:
  - color-editor.js, line 135

##### Returns:

String with a div where the background color is set as the value that's passed in.

Type
  string